View source: R/upsilon.statistic.R
| upsilon.statistic | R Documentation |
Calculates the Upsilon test statistic \Upsilon.
upsilon.statistic(x)
x |
a matrix or data frame of floating or integer numbers to specify a contingency table. Entries must be non-negative. |
The Upsilon test is designed to promote dominant function patterns. In contrast to other tests of association to favor all function patterns, it is unique in demoting non-dominant function patterns.
Null hypothesis (H_0): Row and column variables are
statistically independent.
Null population: A discrete uniform distribution, where each entry in the table has the same probability.
Null distribution: The Upsilon test statistic
asymptotically follows a chi-squared distribution
with (nrow(x) - 1)(ncol(x) - 1) degrees of freedom,
under the null hypothesis on the null population.
See \insertCiteluo2021upsilonUpsilon for full details of the Upsilon test.
The numeric value of Upsilon test statistic \Upsilon.
luo2021upsilonUpsilon
library("Upsilon")
# Create a contingency table
x <- matrix(c(
0, 3, 0,
3, 0, 0),
nrow = 2, byrow = TRUE)
print(x)
# Calculate statistic
upsilon.statistic(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.